==> ejc-law-impl-3.0.0-20221123.002750-29-sources.jar: com/ejianc/business/law/controller/ProsecutionInfoRegisterController.java <==
package com.ejianc.business.law.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ejianc.business.law.bean.InfoRegisterEntity;
import com.ejianc.business.law.bean.LedgerEntity;
import com.ejianc.business.law.bean.ProsecutionCaseRegisterEntity;
import com.ejianc.business.law.service.ILedgerService;
import com.ejianc.business.law.service.IProsecutionCaseRegisterService;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;

import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;

import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.law.bean.ProsecutionInfoRegisterEntity;
import com.ejianc.business.law.service.IProsecutionInfoRegisterService;
import com.ejianc.business.law.vo.ProsecutionInfoRegisterVO;

/**
 * 起诉案件审理信息登记表
 *
 * @author generator
 */
@Controller
@RequestMapping("prosecutionInfoRegister")
public class ProsecutionInfoRegisterController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private IProsecutionInfoRegisterService service;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<ProsecutionInfoRegisterVO> saveOrUpdate(@RequestBody ProsecutionInfoRegisterVO saveOrUpdateVO) {
        ProsecutionInfoRegisterEntity entity = BeanMapper.map(saveOrUpdateVO, ProsecutionInfoRegisterEntity.class);
        UserContext userContextCache = sessionManager.getUserContext();
        if (entity.getId() == null || entity.getId() == 0) {
            //设置创建人姓名
            entity.setCreateUserName(userContextCache.getUserName());
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE, InvocationInfoProxy.getTenantid(), saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if (billCode.isSuccess()) {
                //entity.setCode(billCode.getData());//此处需要根据实际修改删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改删除本行或者上一行
            } else {
                throw new BusinessException("网络异常，编码生成失败，请稍后再试");
            }
        } else {
            //设置修改人姓名
            entity.setUpdateUserName(userContextCache.getUserName());
        }
        service.saveOrUpdate(entity, false);
        //案件台账关联更新
        ledgerSaveOrUpdate(entity);
        //案件登记关联更新
        updateCaseRegister(entity);

        ProsecutionInfoRegisterVO vo = BeanMapper.map(entity, ProsecutionInfoRegisterVO.class);
        return CommonResponse.success("保存或修改单据成功！", vo);
    }

    /**
     * @param id
     * @Description queryDetail 查询详情
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<ProsecutionInfoRegisterVO> queryDetail(Long id) {
        ProsecutionInfoRegisterEntity entity = service.selectById(id);
        ProsecutionInfoRegisterVO vo = BeanMapper.map(entity, ProsecutionInfoRegisterVO.class);
        return CommonResponse.success("查询详情数据成功！", vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<ProsecutionInfoRegisterVO> vos) {
        if (ListUtil.isNotEmpty(vos)) {
            for (ProsecutionInfoRegisterVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(ProsecutionInfoRegisterVO::getId).collect(Collectors.toList()), true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @param param
     * @Description queryList 查询列表
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<ProsecutionInfoRegisterVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache = sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if (StringUtils.isNotBlank(authOrgIds)) {//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        } else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if (5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });
        if (CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if (CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("projectDepartmentId", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<ProsecutionInfoRegisterEntity> page = service.queryPage(param, false);
        IPage<ProsecutionInfoRegisterVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), ProsecutionInfoRegisterVO.class));

        return CommonResponse.success("查询列表数据成功！", pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if (isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @param param
     * @Description 导出
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<ProsecutionInfoRegisterEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("ProsecutionInfoRegister-export.xlsx", beans, response);
    }

    /**
     * @param param
     * @Description 参照
     * @Return void
     */
    @RequestMapping(value = "/refProsecutionInfoRegisterData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<ProsecutionInfoRegisterVO>> refProsecutionInfoRegisterData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                                           String condition,
                                                                                           String searchObject,
                                                                                           String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if (StringUtils.isNotEmpty(condition)) {
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<ProsecutionInfoRegisterEntity> page = service.queryPage(param, false);
        IPage<ProsecutionInfoRegisterVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), ProsecutionInfoRegisterVO.class));

        return CommonResponse.success("查询参照数据成功！", pageData);
    }

    /**
     * @param
     * @Description queryNum 查询,校验是否重复添加
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryNum", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<Long> queryNum(Long caseId, Integer hearCount) {

        QueryParam param = new QueryParam();

        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        /** 案件编号 */
        param.getParams().put("caseId", new Parameter(QueryParam.EQ, caseId));
        /** 审理阶段 */
        param.getParams().put("hearCount", new Parameter(QueryParam.EQ, hearCount));

        IPage<ProsecutionInfoRegisterEntity> page = service.queryPage(param, false);

        return CommonResponse.success(page.getTotal());
    }

    /**
     * 起诉案件信息登记表关联更新
     */
    @Autowired
    private IProsecutionCaseRegisterService prosecutionCaseRegisterService;

    public void updateCaseRegister(ProsecutionInfoRegisterEntity entity) {
        ProsecutionCaseRegisterEntity prosecutionCaseRegisterEntity = prosecutionCaseRegisterService.getById(entity.getCaseId());
        prosecutionCaseRegisterEntity.setHearCount(entity.getHearCount());
        prosecutionCaseRegisterEntity.setCaseStateName(entity.getFirstResultName());//案件状态
//        prosecutionCaseRegisterEntity.setCaseResult(entity.getFirstResultName());//案件结果
        prosecutionCaseRegisterEntity.setThirdEndDate(entity.getFirstEndDate());//结案日期
//        prosecutionCaseRegisterEntity.setThirdEndAmount(entity.getFirstEndAmount());//结案金额

        prosecutionCaseRegisterService.saveOrUpdate(prosecutionCaseRegisterEntity);
    }


    /**
     * 起诉案件台账关联更新
     */
    @Autowired
    private ILedgerService ledgerService;

    private void ledgerSaveOrUpdate(ProsecutionInfoRegisterEntity entity) {
        LedgerEntity ledgerEntity = ledgerService.getOne(Wrappers.<LedgerEntity>lambdaQuery().eq(LedgerEntity::getCaseId, entity.getCaseId()));
        if (ledgerEntity != null) {
            ledgerEntity.setId(ledgerEntity.getId());
            ledgerEntity.setCaseResultId(entity.getFirstResultId());//案件结果
            ledgerEntity.setCaseResultName(entity.getFirstResultName());
            ledgerEntity.setEndAmount(entity.getFirstEndAmount());//结案金额
            ledgerEntity.setEndDate(entity.getFirstEndDate());//结案日期
            ledgerEntity.setInfoId(entity.getId());//案件审理信息id
        }
        ledgerService.saveOrUpdate(ledgerEntity);
    }
}

==> ejc-law-impl-3.0.0-20230830.070935-46-sources.jar: com/ejianc/business/law/controller/ProsecutionInfoRegisterController.java <==
package com.ejianc.business.law.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ejianc.business.law.bean.InfoRegisterEntity;
import com.ejianc.business.law.bean.LedgerEntity;
import com.ejianc.business.law.bean.ProsecutionCaseRegisterEntity;
import com.ejianc.business.law.service.ILedgerService;
import com.ejianc.business.law.service.IProsecutionCaseRegisterService;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;

import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;

import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.law.bean.ProsecutionInfoRegisterEntity;
import com.ejianc.business.law.service.IProsecutionInfoRegisterService;
import com.ejianc.business.law.vo.ProsecutionInfoRegisterVO;

/**
 * 起诉案件审理信息登记表
 *
 * @author generator
 */
@Controller
@RequestMapping("prosecutionInfoRegister")
public class ProsecutionInfoRegisterController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private IProsecutionInfoRegisterService service;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<ProsecutionInfoRegisterVO> saveOrUpdate(@RequestBody ProsecutionInfoRegisterVO saveOrUpdateVO) {
        ProsecutionInfoRegisterEntity entity = BeanMapper.map(saveOrUpdateVO, ProsecutionInfoRegisterEntity.class);
        UserContext userContextCache = sessionManager.getUserContext();
        if (entity.getId() == null || entity.getId() == 0) {
            //设置创建人姓名
            entity.setCreateUserName(userContextCache.getUserName());
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE, InvocationInfoProxy.getTenantid(), saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if (billCode.isSuccess()) {
                //entity.setCode(billCode.getData());//此处需要根据实际修改删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改删除本行或者上一行
            } else {
                throw new BusinessException("网络异常，编码生成失败，请稍后再试");
            }
        } else {
            //设置修改人姓名
            entity.setUpdateUserName(userContextCache.getUserName());
        }
        service.saveOrUpdate(entity, false);
//        //案件台账关联更新
//        ledgerSaveOrUpdate(entity);
        //案件登记关联更新
        updateCaseRegister(entity);

        ProsecutionInfoRegisterVO vo = BeanMapper.map(entity, ProsecutionInfoRegisterVO.class);
        return CommonResponse.success("保存或修改单据成功！", vo);
    }

    /**
     * @param id
     * @Description queryDetail 查询详情
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<ProsecutionInfoRegisterVO> queryDetail(Long id) {
        ProsecutionInfoRegisterEntity entity = service.selectById(id);
        ProsecutionInfoRegisterVO vo = BeanMapper.map(entity, ProsecutionInfoRegisterVO.class);
        return CommonResponse.success("查询详情数据成功！", vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<ProsecutionInfoRegisterVO> vos) {
        if (ListUtil.isNotEmpty(vos)) {
            for (ProsecutionInfoRegisterVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(ProsecutionInfoRegisterVO::getId).collect(Collectors.toList()), true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @param param
     * @Description queryList 查询列表
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<ProsecutionInfoRegisterVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache = sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if (StringUtils.isNotBlank(authOrgIds)) {//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        } else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if (5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });
        if (CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if (CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("projectDepartmentId", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<ProsecutionInfoRegisterEntity> page = service.queryPage(param, false);
        IPage<ProsecutionInfoRegisterVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), ProsecutionInfoRegisterVO.class));

        return CommonResponse.success("查询列表数据成功！", pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if (isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @param param
     * @Description 导出
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<ProsecutionInfoRegisterEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("ProsecutionInfoRegister-export.xlsx", beans, response);
    }

    /**
     * @param param
     * @Description 参照
     * @Return void
     */
    @RequestMapping(value = "/refProsecutionInfoRegisterData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<ProsecutionInfoRegisterVO>> refProsecutionInfoRegisterData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                                           String condition,
                                                                                           String searchObject,
                                                                                           String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if (StringUtils.isNotEmpty(condition)) {
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<ProsecutionInfoRegisterEntity> page = service.queryPage(param, false);
        IPage<ProsecutionInfoRegisterVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), ProsecutionInfoRegisterVO.class));

        return CommonResponse.success("查询参照数据成功！", pageData);
    }

    /**
     * @param
     * @Description queryNum 查询,校验是否重复添加
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryNum", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<Long> queryNum(Long caseId, Integer hearCount) {

        QueryParam param = new QueryParam();

        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        /** 案件编号 */
        param.getParams().put("caseId", new Parameter(QueryParam.EQ, caseId));
        /** 审理阶段 */
        param.getParams().put("hearCount", new Parameter(QueryParam.EQ, hearCount));

        IPage<ProsecutionInfoRegisterEntity> page = service.queryPage(param, false);

        return CommonResponse.success(page.getTotal());
    }

    /**
     * 起诉案件信息登记表关联更新
     */
    @Autowired
    private IProsecutionCaseRegisterService prosecutionCaseRegisterService;

    public void updateCaseRegister(ProsecutionInfoRegisterEntity entity) {
        ProsecutionCaseRegisterEntity prosecutionCaseRegisterEntity = prosecutionCaseRegisterService.getById(entity.getCaseId());
        prosecutionCaseRegisterEntity.setHearCount(entity.getHearCount());
        prosecutionCaseRegisterEntity.setFirstResultName(entity.getFirstResultName());//案件结果
        prosecutionCaseRegisterEntity.setFirstEndDate(entity.getFirstEndDate());//结案日期
        prosecutionCaseRegisterEntity.setFirstEndAmount(entity.getFirstEndAmount());//结案金额

        prosecutionCaseRegisterService.saveOrUpdate(prosecutionCaseRegisterEntity);
    }


    /**
     * 起诉案件台账关联更新
     */
    @Autowired
    private ILedgerService ledgerService;

    private void ledgerSaveOrUpdate(ProsecutionInfoRegisterEntity entity) {
        LedgerEntity ledgerEntity = ledgerService.getOne(Wrappers.<LedgerEntity>lambdaQuery().eq(LedgerEntity::getCaseId, entity.getCaseId()));
        if (ledgerEntity != null) {
            ledgerEntity.setId(ledgerEntity.getId());
            ledgerEntity.setCaseResultId(entity.getFirstResultId());//案件结果
            ledgerEntity.setCaseResultName(entity.getFirstResultName());
            ledgerEntity.setEndAmount(entity.getFirstEndAmount());//结案金额
            ledgerEntity.setEndDate(entity.getFirstEndDate());//结案日期
            ledgerEntity.setInfoId(entity.getId());//案件审理信息id
        }
        ledgerService.saveOrUpdate(ledgerEntity);
    }
}
